# gaussianDistributionML
Pypi package for calculation of Gaussian Distribution

## Installation
* To install my package please run: ```$ pip install requirements.txt```

## Usage
* Import package
```python
from distributions import Gaussian
```

* Example of usage:
```python
gaussian_one = Gaussian(25, 2)
gaussian_one.mean
gaussian_one + gaussian_one
```